@@ -43,9 +43,6 @@ void             goa_object_skeleton_attach_files          (GoaObjectSkeleton *o
                                                             gboolean           files_enabled,
                                                             gboolean           accept_ssl_errors);
 
-void             goa_object_skeleton_attach_maps           (GoaObjectSkeleton *object,
-                                                            gboolean           maps_enabled);
-
 void             goa_object_skeleton_attach_photos         (GoaObjectSkeleton *object,
                                                             gboolean           photos_enabled);
 
